# LOUVRE - Accessing JPG data

## Usage

Install

```bash
poetry config virtualenvs.in-project true
poetry install
```

Tests

```bash
poetry run pytest
```

Publish

```bash
poetry publish --build
```